OverrideStack

Struct OverrideStack 

pub struct OverrideStack(/* private fields */);
A stack of OverrideMap values capturing our precedence rules.

Items toward the top of the stack (later in the backing Vec) have higher precedence and override items lower in the stack. If an override is set and not None for a given lint in multiple maps in the stack, the value at the top of the stack will be used to calculate the effective lint level or required version update.

Implementations

Source

impl OverrideStack

pub fn new() -> Self

Creates a new, empty OverrideStack instance.

pub fn push(&mut self, item: &OverrideMap)

Inserts the given map at the top of the stack.

The inserted overrides will take precedence over any lower item in the stack, if both maps have a not-None entry for a given lint.

pub fn effective_lint_level(&self, query: &SemverQuery) -> LintLevel

Calculates the effective lint level of this query, by searching for an override mapped to this query’s id from the top of the stack first, returning the query’s default lint level if not overridden.

pub fn effective_required_update( &self, query: &SemverQuery, ) -> RequiredSemverUpdate

Calculates the effective required version bump of this query, by searching for an override mapped to this query’s id from the top of the stack first, returning the query’s default required version bump if not overridden.