#[non_exhaustive]pub struct SemverQuery {
pub id: String,
pub description: String,
pub required_update: RequiredSemverUpdate,
pub lint_level: LintLevel,
pub reference: Option<String>,
pub reference_link: Option<String>,
pub witness: Option<Witness>,
/* private fields */
}Expand description
A query that can be executed on a pair of rustdoc output files, returning instances of a particular kind of semver violation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Stringdescription: Stringrequired_update: RequiredSemverUpdatelint_level: LintLevelThe default lint level for when this lint occurs.
reference: Option<String>reference_link: Option<String>witness: Option<Witness>Optional data to create witness code for query output. See the Witness struct for
more information.
Implementations
Sourceimpl SemverQuery
impl SemverQuery
Sourcepub fn from_ron_str(query_text: &str) -> Result<Self>
pub fn from_ron_str(query_text: &str) -> Result<Self>
Deserializes a SemverQuery from a ron-encoded string slice.
Returns an Err if the deserialization fails.
pub fn all_queries() -> BTreeMap<String, SemverQuery>