Rustdoc

Struct Rustdoc 

#[non_exhaustive]
pub struct Rustdoc { /* private fields */ }

Implementations

Source

impl Rustdoc

pub fn from_path(rustdoc_path: impl Into<PathBuf>) -> Self

Use an existing rustdoc file.

pub fn from_root(project_root: impl Into<PathBuf>) -> Self

Generate the rustdoc file from the project root directory, i.e. the directory containing the crate source. It can be a workspace or a single package. Same as Rustdoc::from_git_revision(), but with the current git revision.

pub fn from_git_revision( project_root: impl Into<PathBuf>, revision: impl Into<String>, ) -> Self

Generate the rustdoc file from the project at a given git revision.

pub fn from_registry_latest_crate_version() -> Self

Generate the rustdoc file from the largest-numbered non-yanked non-prerelease version published to the cargo registry. If no such version, uses the largest-numbered version including yanked and prerelease versions.

pub fn from_registry(crate_version: impl Into<String>) -> Self

Generate the rustdoc file from a specific crate version.